/****************************************************************************
** Meta object code from reading C++ file 'xdgmenurules.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libqtxdg-2.0.0/qtxdg/xdgmenurules.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xdgmenurules.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_XdgMenuRule_t {
    QByteArrayData data[1];
    char stringdata0[12];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XdgMenuRule_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XdgMenuRule_t qt_meta_stringdata_XdgMenuRule = {
    {
QT_MOC_LITERAL(0, 0, 11) // "XdgMenuRule"

    },
    "XdgMenuRule"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XdgMenuRule[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XdgMenuRule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XdgMenuRule::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XdgMenuRule.data,
      qt_meta_data_XdgMenuRule,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *XdgMenuRule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XdgMenuRule::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_XdgMenuRule.stringdata0))
        return static_cast<void*>(const_cast< XdgMenuRule*>(this));
    return QObject::qt_metacast(_clname);
}

int XdgMenuRule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_XdgMenuRuleOr_t {
    QByteArrayData data[1];
    char stringdata0[14];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XdgMenuRuleOr_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XdgMenuRuleOr_t qt_meta_stringdata_XdgMenuRuleOr = {
    {
QT_MOC_LITERAL(0, 0, 13) // "XdgMenuRuleOr"

    },
    "XdgMenuRuleOr"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XdgMenuRuleOr[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XdgMenuRuleOr::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XdgMenuRuleOr::staticMetaObject = {
    { &XdgMenuRule::staticMetaObject, qt_meta_stringdata_XdgMenuRuleOr.data,
      qt_meta_data_XdgMenuRuleOr,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *XdgMenuRuleOr::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XdgMenuRuleOr::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_XdgMenuRuleOr.stringdata0))
        return static_cast<void*>(const_cast< XdgMenuRuleOr*>(this));
    return XdgMenuRule::qt_metacast(_clname);
}

int XdgMenuRuleOr::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XdgMenuRule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_XdgMenuRuleAnd_t {
    QByteArrayData data[1];
    char stringdata0[15];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XdgMenuRuleAnd_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XdgMenuRuleAnd_t qt_meta_stringdata_XdgMenuRuleAnd = {
    {
QT_MOC_LITERAL(0, 0, 14) // "XdgMenuRuleAnd"

    },
    "XdgMenuRuleAnd"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XdgMenuRuleAnd[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XdgMenuRuleAnd::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XdgMenuRuleAnd::staticMetaObject = {
    { &XdgMenuRuleOr::staticMetaObject, qt_meta_stringdata_XdgMenuRuleAnd.data,
      qt_meta_data_XdgMenuRuleAnd,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *XdgMenuRuleAnd::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XdgMenuRuleAnd::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_XdgMenuRuleAnd.stringdata0))
        return static_cast<void*>(const_cast< XdgMenuRuleAnd*>(this));
    return XdgMenuRuleOr::qt_metacast(_clname);
}

int XdgMenuRuleAnd::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XdgMenuRuleOr::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_XdgMenuRuleNot_t {
    QByteArrayData data[1];
    char stringdata0[15];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XdgMenuRuleNot_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XdgMenuRuleNot_t qt_meta_stringdata_XdgMenuRuleNot = {
    {
QT_MOC_LITERAL(0, 0, 14) // "XdgMenuRuleNot"

    },
    "XdgMenuRuleNot"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XdgMenuRuleNot[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XdgMenuRuleNot::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XdgMenuRuleNot::staticMetaObject = {
    { &XdgMenuRuleOr::staticMetaObject, qt_meta_stringdata_XdgMenuRuleNot.data,
      qt_meta_data_XdgMenuRuleNot,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *XdgMenuRuleNot::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XdgMenuRuleNot::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_XdgMenuRuleNot.stringdata0))
        return static_cast<void*>(const_cast< XdgMenuRuleNot*>(this));
    return XdgMenuRuleOr::qt_metacast(_clname);
}

int XdgMenuRuleNot::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XdgMenuRuleOr::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_XdgMenuRuleFileName_t {
    QByteArrayData data[1];
    char stringdata0[20];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XdgMenuRuleFileName_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XdgMenuRuleFileName_t qt_meta_stringdata_XdgMenuRuleFileName = {
    {
QT_MOC_LITERAL(0, 0, 19) // "XdgMenuRuleFileName"

    },
    "XdgMenuRuleFileName"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XdgMenuRuleFileName[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XdgMenuRuleFileName::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XdgMenuRuleFileName::staticMetaObject = {
    { &XdgMenuRule::staticMetaObject, qt_meta_stringdata_XdgMenuRuleFileName.data,
      qt_meta_data_XdgMenuRuleFileName,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *XdgMenuRuleFileName::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XdgMenuRuleFileName::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_XdgMenuRuleFileName.stringdata0))
        return static_cast<void*>(const_cast< XdgMenuRuleFileName*>(this));
    return XdgMenuRule::qt_metacast(_clname);
}

int XdgMenuRuleFileName::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XdgMenuRule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_XdgMenuRuleCategory_t {
    QByteArrayData data[1];
    char stringdata0[20];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XdgMenuRuleCategory_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XdgMenuRuleCategory_t qt_meta_stringdata_XdgMenuRuleCategory = {
    {
QT_MOC_LITERAL(0, 0, 19) // "XdgMenuRuleCategory"

    },
    "XdgMenuRuleCategory"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XdgMenuRuleCategory[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XdgMenuRuleCategory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XdgMenuRuleCategory::staticMetaObject = {
    { &XdgMenuRule::staticMetaObject, qt_meta_stringdata_XdgMenuRuleCategory.data,
      qt_meta_data_XdgMenuRuleCategory,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *XdgMenuRuleCategory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XdgMenuRuleCategory::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_XdgMenuRuleCategory.stringdata0))
        return static_cast<void*>(const_cast< XdgMenuRuleCategory*>(this));
    return XdgMenuRule::qt_metacast(_clname);
}

int XdgMenuRuleCategory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XdgMenuRule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_XdgMenuRuleAll_t {
    QByteArrayData data[1];
    char stringdata0[15];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XdgMenuRuleAll_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XdgMenuRuleAll_t qt_meta_stringdata_XdgMenuRuleAll = {
    {
QT_MOC_LITERAL(0, 0, 14) // "XdgMenuRuleAll"

    },
    "XdgMenuRuleAll"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XdgMenuRuleAll[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XdgMenuRuleAll::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XdgMenuRuleAll::staticMetaObject = {
    { &XdgMenuRule::staticMetaObject, qt_meta_stringdata_XdgMenuRuleAll.data,
      qt_meta_data_XdgMenuRuleAll,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *XdgMenuRuleAll::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XdgMenuRuleAll::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_XdgMenuRuleAll.stringdata0))
        return static_cast<void*>(const_cast< XdgMenuRuleAll*>(this));
    return XdgMenuRule::qt_metacast(_clname);
}

int XdgMenuRuleAll::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XdgMenuRule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_XdgMenuRules_t {
    QByteArrayData data[1];
    char stringdata0[13];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XdgMenuRules_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XdgMenuRules_t qt_meta_stringdata_XdgMenuRules = {
    {
QT_MOC_LITERAL(0, 0, 12) // "XdgMenuRules"

    },
    "XdgMenuRules"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XdgMenuRules[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void XdgMenuRules::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject XdgMenuRules::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_XdgMenuRules.data,
      qt_meta_data_XdgMenuRules,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *XdgMenuRules::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XdgMenuRules::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_XdgMenuRules.stringdata0))
        return static_cast<void*>(const_cast< XdgMenuRules*>(this));
    return QObject::qt_metacast(_clname);
}

int XdgMenuRules::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
QT_END_MOC_NAMESPACE
